Shared template helpers for the wagoe CLI: template loading, {{var}} rendering, and AGENTS.md's marker-delimited blocks.
Shared template helpers for the wagoe CLI: template loading, {{var}}
rendering, and AGENTS.md's marker-delimited blocks.(block-content content block)Content between the first marker pair (exclusive), or nil when absent.
Content between the first marker pair (exclusive), or nil when absent.
(read-template tmpl-name)Slurp a template from the CLI's resources. Throws when missing.
Slurp a template from the CLI's resources. Throws when missing.
(render template substitutions)Replace {{key}} placeholders in template with substitution values.
Replace {{key}} placeholders in template with substitution values.
(replace-block target block new-body)Replace the content of the first marker pair in target with new-body. Returns target unchanged when the markers are missing.
Replace the content of the first marker pair in target with new-body. Returns target unchanged when the markers are missing.
(update-block content block f)Apply f to the body of the first marker pair; no-op when markers absent.
Apply f to the body of the first marker pair; no-op when markers absent.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |